@@ -1,5 +1,5 @@
 package Test::Mock::Wrapper;
-$Test::Mock::Wrapper::VERSION = '0.06.1';
+$Test::Mock::Wrapper::VERSION = '0.001';
 use strict;
 use warnings;
 use base qw(Exporter);
@@ -17,12 +17,10 @@ Test::Mock::Wrapper
 
 =head1 VERSION
 
-version 0.06.1
+version 0.001
 
 =head1 SYNOPSIS
 
-=head2 Mock a single instance of an object
-
     use Test::Mock::Wrapper;
     use Foo;
     
@@ -35,24 +33,6 @@ version 0.06.1
     
     $wrapper->verify('bar')->with(['baz'])->once;
 
-=head2 Mock an entire package
-
-    use Test::Mock::Wrapper;
-    use Foo;
-    
-    my $wrapper = Test::Mock::Wrapper->new('Foo');
-    
-    $wrapper->addMock('bar', with=>['baz'], returns=>'snarf');
-    
-    &callBar(Foo->new);
-    
-    $wrapper->verify('bar')->with(['baz'])->once;
-    
-    $wrapper->DESTROY;
-    
-    my $actualFoo = Foo->new;
-    
-    
 =head1 DESCRIPTION
 
 This is another module for mocking objects in perl.  It will wrap around an existing object, allowing you to mock any calls
@@ -65,12 +45,6 @@ methods are designed to be chainable for easily readable tests for example:
   # Verify method 'baz' was called at least 2 times, but not more than 5 times
   $mockWrapper->verify('baz')->at_least(2)->at_most(5);
 
-Test::Mock::Wrapper can also be used to wrap an entire package.  When this is done, Test::Mock::Wrapper will actually use
-L<metaclass> to alter the symbol table an wrap all methods in the package. The same rules about mocking type (see options to
-new below) apply to mocked packages, but you only get one wrapper that records and mocks calls to all instances of the package,
-and any package methods called outside of an object. When mocking an entire package, destroying the wrapper object will "unwrap"
-the package, restoring the symbol table to is original unmocked state. Objects instantiated before the wrapper was destroyed
-may not behave correctly (i.e. throw exceptions).
 
 =head1 METHODS
 
@@ -122,23 +96,18 @@ sub new {
     my $controll = bless({__object=>$object, __mocks=>{}, __calls=>{}, __options=>\%options}, $class);
     $controll->{__mocked} = Test::Mock::Wrapped->new($controll, $object);
     if (! ref($object)) {
-	eval "package $object; use metaclass;";  
-	my $metaclass = $object->meta;
-
-	$metaclass->make_mutable if($metaclass->is_immutable);
-
-	$controll->{__metaclass} = $metaclass;
-	foreach my $method_name ($metaclass->get_method_list){
-	    push @{ $controll->{__wrapped_symbols} }, {name => $method_name, symbol => $metaclass->find_method_by_name($method_name)};
-	    $controll->{__symbols}{$method_name} = $metaclass->find_method_by_name($method_name)->body;
-	    if ($method_name eq 'new') {
-		my $method = $metaclass->remove_method($method_name);
-		$metaclass->add_method($method_name, sub{ return bless {}, $object; });
-		
-	    }else{
-		my $method = $metaclass->remove_method($method_name);
-		$metaclass->add_method($method_name, sub{ $controll->_call($method_name, @_); });
+	no strict qw(refs);
+	no warnings 'redefine';
+	foreach my $sym (keys %{ $object .'::'}){
+	    if ($sym eq 'new') {
+		push @{ $controll->{__wrapped_symbols} }, {name => $object.'::'.$sym, symbol => \&{ $object.'::'.$sym }};
+		*{ $object.'::'.$sym } = sub { return $controll->{__mocked} };
 	    }
+	    elsif (defined &{ $object.'::'.$sym }) {
+		push @{ $controll->{__wrapped_symbols} }, {name => $object.'::'.$sym, symbol => \&{ $object.'::'.$sym }};
+		*{ $object.'::'.$sym } = sub { $controll->_call($sym, @_); };
+	    }
+	    
 	}
     }
     return $controll;
@@ -147,13 +116,9 @@ sub new {
 sub DESTROY {
     my $controll = shift;
     no strict qw(refs);
-    no warnings 'redefine', 'prototype';
-    if ($controll->{__metaclass}) {
-	foreach my $sym (@{ $controll->{__wrapped_symbols} }){
-	    if ($sym->{symbol}) {
-		$controll->{__metaclass}->add_method($sym->{name}, $sym->{symbol}->body);
-	    }
-	}
+    no warnings 'redefine';
+    foreach my $sym (@{ $controll->{__wrapped_symbols} }){
+	*{ $sym->{name} } = $sym->{symbol};
     }
 }
 
@@ -170,41 +135,6 @@ sub getObject {
     return $self->{__mocked};
 }
 
-=item $wrapper->resetCalls([$method])
-
-This method clears out the memory of calls that have been made, which is usefull if using the same mock wrapper instance
-multiple tests. When called without arguments, all call history is cleared.  With the optional $method argument, only
-history for that method is called.
-
-=cut
-
-sub resetCalls {
-    my($self, $method) = @_;
-    if (defined($method) && length($method)) {
-	$self->{__calls}{$method} = [];
-    }else{
-	$self->{__calls} = {};
-    }
-    return 1;
-}
-
-=item $wrapper->resetMocks([$method])
-
-This method clears out all previously provided mocked methods. Without arguments, all mocks are cleared. With the optional
-$method argument, only mocks for that method are cleared.
-
-=cut
-
-sub resetMocks {
-    my($self, $method) = @_;
-    if (defined($method) && length($method)) {
-	delete $self->{__mocks}{$method};
-    }else{
-	$self->{__mocks} = {};
-    }
-    return 1;
-}
-
 sub _call {
     my $self = shift;
     my $method = shift;
@@ -216,7 +146,7 @@ sub _call {
 	my $return_offset = 0;
 	foreach my $test_set (@{ $self->{__mocks}{$method}{with} }){
 	    if(eq_deeply(\@_, $test_set)){
-		return ref $self->{__mocks}{$method}{conditional_return}[$return_offset] eq 'ARRAY' ? @{$self->{__mocks}{$method}{conditional_return}[$return_offset]} : $self->{__mocks}{$method}{conditional_return}[$return_offset];
+		return $self->{__mocks}{$method}{conditional_return}[$return_offset];
 	    }
 	    $return_offset++;
 	}
@@ -226,7 +156,7 @@ sub _call {
     # If we've gotten here, we did not find an argument specific return
     if(exists $self->{__mocks}{$method}{returns}){
 	# I we have a default, use it
-	return ref $self->{__mocks}{$method}{returns} eq 'ARRAY' ? @{ $self->{__mocks}{$method}{returns} } : $self->{__mocks}{$method}{returns}; 
+	return $self->{__mocks}{$method}{returns};
     }
     elsif($self->{__options}{type} ne 'wrap'){
 	# No default, type equals stub or mock, return undef.
@@ -235,13 +165,7 @@ sub _call {
     else{
 	# We do not have a default, and our mock type is not stub or mock, try to call underlying object.
 	unshift @_, $self->{__object}; 
-	if ($self->{__metaclass}) {
-	    # Pacakge is mocked with method wrappers, must call the original symbol metaclass
-	    goto &{ $self->{__symbols}{$method} };
-	}else{
-	    goto &{ ref($self->{__object}).'::'.$method };
-	}
-	
+	goto &{ ref($self->{__object}).'::'.$method };
     }
 }
 
@@ -254,15 +178,6 @@ This method is used to add a new mocked method call. Currently supports two opti
 =item * B<returns> used to specify a value to be returned when the method is called.
 
     $wrapper->addMock('foo', returns=>'bar')
-    
-Note: if "returns" recieves an array refernce, it will return it as an array.  To return an actual
-array reference, wrap it in another reference.
-
-    $wrapper->addMock('foo', returns=>['Dave', 'Fred', 'Harry'])
-    my(@names) = $wrapper->getObject->foo;
-    
-    $wrapper->addMock('baz', returns=>[['Dave', 'Fred', 'Harry']]);
-    my($rnames) = $wrapper->getObject->baz;
 
 =item * B<with> used to limit the scope of the mock based on the value of the arguments.  Test::Deep's eq_deeply is used to
 match against the provided arguments, so any syntax supported there will work with Test::Mock::Wrapper;
@@ -392,12 +307,10 @@ sub verify {
     return Test::Mock::Wrapper::Verify->new($method, $self->{__calls}{$method});    
 }
 
-
 package Test::Mock::Wrapped;
-$Test::Mock::Wrapped::VERSION = '0.06.1';
+$Test::Mock::Wrapped::VERSION = '0.001';
 use Carp;
 use Scalar::Util qw(weaken isweak);
-use vars qw(@ISA);
 
 sub new {
     my($proto, $controller, $object) = @_;
@@ -439,4 +352,4 @@ return 42;
 This software is copyright (c) 2015 by Dave Mueller.
 
 This is free software; you can redistribute it and/or modify it under the
-same terms as the Perl 5 programming language system itself.
+same terms as the Perl 5 programming language system itself.
\ No newline at end of file
